@@ -37,8 +37,12 @@ class AntiAnalysis(Module):
         self.ntdll: WinDLL = ctypes.windll.ntdll
 
     @property
-    def name(self):
+    def name(self) -> str:
         return "Anti Analysis"
+    
+    @property
+    def version(self) -> int:
+        return 1.0
 
     def CheckDebugPrivilege(self) -> None:
         hToken = ctypes.c_void_p()
@@ -78,13 +82,16 @@ class AntiAnalysis(Module):
                         "debug_privilege_found",
                         "Debug Privilege Enabled",
                         self.name)
+                    self.event.dispatch(
+                        "pyprotector_detect",
+                        "Debug Privilege Enabled",
+                        self.name)
                 if self.exit:
                     os._exit(1)
 
         self.ntdll.NtClose(hToken)
 
     def HideThreads(self) -> None:
-        self.logger.info("Hiding Threads")
         PID = self.kernel32.GetCurrentProcessId()
         hProcess = self.kernel32.OpenProcess(0x1F0FFF, False, PID)
         if hProcess is None:
@@ -103,7 +110,6 @@ class AntiAnalysis(Module):
 
         self.kernel32.CloseHandle(hThread)
         self.kernel32.CloseHandle(hProcess)
-        self.logger.info("Threads Hidden")
 
     def CheckDebugObject(self) -> None:
         PID = self.kernel32.GetCurrentProcessId()
@@ -132,6 +138,11 @@ class AntiAnalysis(Module):
                     "Debug Object Handle Detected",
                     self.name,
                 )
+                self.event.dispatch(
+                    "pyprotector_detect",
+                    "Debug Object Handle Detected",
+                    self.name,
+                )
             if self.exit:
                 os._exit((1))
 
@@ -160,6 +171,10 @@ class AntiAnalysis(Module):
                 self.event.dispatch(
                     "se_debug_name", "Debug Object Handle Detected", self.name
                 )
+                self.event.dispatch(
+                    "pyprotector_detect",
+                    "Debug Object Handle Detected",
+                    self.name)
             if self.exit:
                 os._exit((1))
 
@@ -191,6 +206,11 @@ class AntiAnalysis(Module):
                     "NT_GLOBAL_FLAG_DEBUGGED Found in the Process Environment Block",
                     self.name,
                 )
+                self.event.dispatch(
+                    "pyprotector_detect",
+                    "NT_GLOBAL_FLAG_DEBUGGED Found in the Process Environment Block",
+                    self.name,
+                )
             if self.exit:
                 os._exit(1)
 
@@ -221,6 +241,11 @@ class AntiAnalysis(Module):
                     "Hardware Breakpoints Found Set",
                     self.name,
                 )
+                self.event.dispatch(
+                    "pyprotector_detect",
+                    "Hardware Breakpoints Found Set",
+                    self.name,
+                )
             if self.exit:
                 os._exit(1)
 
@@ -242,6 +267,10 @@ class AntiAnalysis(Module):
                     "debug_filter_state",
                     "Debug Filter State is not 0",
                     self.name)
+                self.event.dispatch(
+                    "pyprotector_detect",
+                    "Debug Filter State is not 0",
+                    self.name)
             if self.exit:
                 os._exit(1)
 
@@ -264,11 +293,16 @@ class AntiAnalysis(Module):
                     "peb_being_debugged",
                     "Process Found Being Debugged",
                     self.name)
+                self.event.dispatch(
+                    "pyprotector_detect",
+                    "Process Found Being Debugged",
+                    self.name)
             if self.exit:
                 os._exit(1)
 
     def StartAnalyzing(self) -> None:
-        self.logger.info("Starting Analysis Checks")
+        if self.report:
+            self.logger.info("Starting Analysis Checks")
         self.CheckDebugPrivilege()
         self.CheckDebugObject()
         self.CheckSEDebugName()
@@ -276,8 +310,11 @@ class AntiAnalysis(Module):
         self.CheckHardwareBreakpoints()
         self.CheckDebugFilterState()
         self.CheckPEB()
-        self.logger.info("Finished All Analysis Checks")
+        if self.report:
+            self.logger.info("Finished All Analysis Checks")
 
-        self.logger.info("Hiding Threads")
+        if self.report:
+            self.logger.info("Hiding Threads")
         self.HideThreads()
-        self.logger.info("Threads Hidden")
+        if self.report:
+            self.logger.info("Threads Hidden")
