@@ -37,8 +37,12 @@ class AntiDLL(Module):
         self.event: Event = event
 
     @property
-    def name(self):
+    def name(self) -> str:
         return "Anti DLL"
+    
+    @property
+    def version(self) -> int:
+        return 1.0
 
     def BlockDLLs(self) -> None:
         while True:
@@ -80,6 +84,13 @@ class AntiDLL(Module):
                             {EvidenceOfSandbox},
                             dlls=EvidenceOfSandbox,
                         )
+                        self.event.dispatch(
+                            "pyprotector_detect",
+                            f"The following DLLs were discovered loaded in processes running on the system. DLLS: {EvidenceOfSandbox}",
+                            self.name,
+                            {EvidenceOfSandbox},
+                            dlls=EvidenceOfSandbox,
+                        )
                     if self.exit:
                         os._exit(1)
             except BaseException:
